{% extends 'utilities/confirmation_form.html' %}
{% load form_helpers %}

{% block title %}Delete {{ obj_type }}?{% endblock %}

{% block message %}
  <p>Are you sure you want to <strong class="text-danger">delete</strong> {{ obj_type }} <strong>{{ obj }}</strong>?</p>
  {% block message_extra %}{% endblock %}
{% endblock message %}
